#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 floskell
version:              0.10.5
visibility:           public
id:                   floskell-0.10.5-Fa4OQheul8s2d6IjjkgI2J
key:                  floskell-0.10.5-Fa4OQheul8s2d6IjjkgI2J
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2020 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  3f96f4cf5289e2029834dcf608fb5b9c
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-8.10.2/site-local/floskell-0.10.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/floskell-0.10.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/floskell-0.10.5
hs-libraries:         HSfloskell-0.10.5-Fa4OQheul8s2d6IjjkgI2J
depends:
    aeson-1.5.4.1-DnAbBYGYPRb2Wb6UPOkxl3
    attoparsec-0.13.2.4-B5Yrk1JgGxD86Mg7HpRzw5 base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    data-default-0.7.1.1-KLr953AsnH0rCiCUM3wfv directory-1.3.6.0
    filepath-1.4.2.1 haskell-src-exts-1.23.1-EhClITPkdeI49dhiNXxDMo
    monad-dijkstra-0.1.1.3-HemDmfVzqN6VmDcwVo2xK mtl-2.2.2 text-1.2.3.2
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-7pOqjd0pRU55sA8Cia2M4w
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

